@@ -1,13 +1,11 @@
 import subprocess
 import random
-from multiprocessing.dummy import Process
 import time
 import sys
 import uuid
 import arrow
 import json
 import base64
-from datetime import datetime
 import os
 import click
 
@@ -19,6 +17,7 @@ from .lib_clickhelpers import AliasedGroup
 from .tools import __empty_dir
 from .tools import abort
 from .tools import __assure_gitignore
+from .tools import _get_available_robottests
 from pathlib import Path
 
 ROBOT_UTILS_GIT = "marcwimmer/odoo-robot_utils"
@@ -30,30 +29,13 @@ def robot(config):
     pass
 
 
-def _get_available_robottests(ctx, param, incomplete):
-    from .robo_helpers import _get_all_robottest_files
-    from .odoo_config import customs_dir
-
-    path = customs_dir() or Path(os.getcwd())
-    path = path / (Path(os.getcwd()).relative_to(path))
-    testfiles = list(map(str, _get_all_robottest_files(path))) or []
-    if incomplete:
-        if "/" in incomplete:
-            testfiles = list(filter(lambda x: str(x).startswith(incomplete), testfiles))
-        else:
-            testfiles = list(filter(lambda x: incomplete in x, testfiles))
-    return sorted(testfiles)
-
-
 @robot.command()
 @pass_config
 @click.pass_context
 def setup(ctx, config):
-    from .module_tools import Module
     from .odoo_config import MANIFEST, customs_dir
     import yaml
 
-
     content = yaml.safe_load(open(customs_dir() / "gimera.yml", "r"))
     for branch in content["repos"]:
         if ROBOT_UTILS_GIT in branch["url"]:
@@ -80,13 +62,35 @@ def setup(ctx, config):
 
     from gimera.gimera import apply as gimera
 
+    _setup_robot_env(config, ctx)
+
     ctx.invoke(gimera, recursive=True, update=True, missing=True)
     if os.getenv("SILENT_ROBOT_SETUP") != "1":
         click.secho(
-            "Create now your first robo test with 'odoo robot new smoketest", fg="green"
+            "Create now your first robo test with 'odoo robot new smoketest",
+            fg="green",
         )
 
 
+def _setup_robot_env(config, ctx):
+    # e.g. for robotcode extension used in vscdoe
+    path = Path(os.path.expanduser("~/.robotenv"))
+    reqfile = config.dirs["images"] / "robot" / "requirements.txt"
+
+    if path.exists():
+        return
+    click.secho(
+        "Setting up virtual environment for robotframework", fg="yellow"
+    )
+    subprocess.run(["python3", "-m", "venv", path], check=True)
+
+    click.secho("Installing requirements for robotframework", fg="yellow")
+    click.secho(reqfile.read_text(), fg="yellow")
+    subprocess.run(
+        [str(path / "bin" / "pip"), "install", "-r", reqfile], check=True
+    )
+
+
 @robot.command(name="new")
 @click.argument("name", required=True)
 @pass_config
@@ -101,7 +105,11 @@ def do_new(ctx, config, name):
     testdir.mkdir(exist_ok=True)
 
     content_file = (
-        customs_dir() / "addons_robot" / "robot_utils" / "tests" / "test_template.robot"
+        customs_dir()
+        / "addons_robot"
+        / "robot_utils"
+        / "tests"
+        / "test_template.robot"
     )
     if not content_file.exists():
         raise Exception(f"File not found: {content_file}")
@@ -115,12 +123,17 @@ def do_new(ctx, config, name):
 
 
 @robot.command()
-@click.argument("file", required=False, shell_complete=_get_available_robottests)
+@click.argument(
+    "file", required=False, shell_complete=_get_available_robottests
+)
 @click.option("-u", "--user", default="admin")
 @click.option("-a", "--all", is_flag=True)
 @click.option("-n", "--test_name", is_flag=False)
 @click.option(
-    "-p", "--param", multiple=True, help="e.g. --param key1=value1 --param key2=value2"
+    "-p",
+    "--param",
+    multiple=True,
+    help="e.g. --param key1=value1 --param key2=value2",
 )
 @click.option("--parallel", default=1, help="Parallel runs of robots.")
 @click.option(
@@ -141,7 +154,9 @@ def do_new(ctx, config, name):
     "-j",
     "--output-json",
     is_flag=True,
-    help=("If set, then a json is printed to console, with detailed informations"),
+    help=(
+        "If set, then a json is printed to console, with detailed informations"
+    ),
 )
 @click.option(
     "--results-file", help="concrete filename where the results.json is stored"
@@ -175,6 +190,11 @@ def do_new(ctx, config, name):
     is_flag=True,
     help="Use Visual Code to debug debugpy - connect the created profile.",
 )
+@click.option(
+    "-M",
+    "--no-install-further-modules",
+    is_flag=True,
+)
 @pass_config
 @click.pass_context
 def run(
@@ -196,12 +216,12 @@ def run(
     min_success_required,
     no_sysexit=False,
     debug=False,
+    no_install_further_modules=False,
 ):
     PARAM = param
     del param
     started = arrow.utcnow()
 
-    from pathlib import Path
     from .odoo_config import customs_dir
     from .module_tools import DBModules
     from .odoo_config import MANIFEST
@@ -210,7 +230,9 @@ def run(
 
     if not config.devmode and not config.force:
         click.secho(
-            ("Devmode required to run unit tests. Database will be destroyed."),
+            (
+                "Devmode required to run unit tests. Database will be destroyed."
+            ),
             fg="red",
         )
         sys.exit(-1)
@@ -228,7 +250,9 @@ def run(
     from .robo_helpers import get_odoo_modules
 
     os.chdir(customs_dir())
-    odoo_modules = set(get_odoo_modules(config.verbose, filenames, customs_dir()))
+    odoo_modules = set(
+        get_odoo_modules(config.verbose, filenames, customs_dir())
+    )
     modules = [("install", "robot_utils")]
     if current_version() < 15.0:
         modules.append(("install", "web_selenium"))
@@ -251,7 +275,7 @@ def run(
                     "CAUTION: Repeat is set, but not force mode, so database is not recreated."
                 )
 
-        if config.force:
+        if config.force and not no_install_further_modules:
             _prepare_fresh_robotest(ctx)
 
         if install_odoo_modules:
@@ -279,7 +303,9 @@ def run(
                     module=install_modules_to_install,
                     no_dangling_check=True,
                 )
-                click.secho(f"Installed modules {','.join(install_modules_to_install)}")
+                click.secho(
+                    f"Installed modules {','.join(install_modules_to_install)}"
+                )
         if uninstall_odoo_modules:
 
             def installed(module):
@@ -288,7 +314,9 @@ def run(
                     abort(f"Could not get state for {module}")
                 return data["state"] == "installed"
 
-            modules_to_uninstall = list(filter(installed, uninstall_odoo_modules))
+            modules_to_uninstall = list(
+                filter(installed, uninstall_odoo_modules)
+            )
             if modules_to_uninstall:
                 click.secho(
                     (
@@ -361,10 +389,10 @@ def _run_test(
 
     manifest = MANIFEST()
     if not browser:
-        browser = "firefox"
+        browser = "chrome"
 
-    if debug:
-        _setup_visual_code_robot(ctx, config)
+    # if debug:
+    #     _setup_visual_code_robot(ctx, config)
 
     pwd = "admin"
     click.secho(
@@ -381,7 +409,7 @@ def _run_test(
             "user": user,
             "dbname": config.DBNAME,
             "password": pwd,
-            "selenium_timeout": timeout,  # selenium timeout,
+            "SELENIUM_TIMEOUT": timeout,  # selenium timeout,
             "parallel": parallel,
             "odoo_version": str(ODOO_VERSION),
             "headless": headless,
@@ -435,6 +463,8 @@ def _run_test(
     output_path = config.HOST_RUN_DIR / "odoo_outdir" / "robot_output"
     from .robo_helpers import _eval_robot_output
 
+    Commands.invoke(ctx, "restart", machines=["seleniumdriver"])
+
     res = _eval_robot_output(
         config,
         output_path,
@@ -456,7 +486,9 @@ def _prepare_fresh_robotest(ctx):
     click.secho("Preparation of tests are done.", fg="yellow")
 
 
-@robot.command(help="Runs all robots defined in section 'robotests' (filepatterns)")
+@robot.command(
+    help="Runs all robots defined in section 'robotests' (filepatterns)"
+)
 @click.option(
     "--timeout",
     required=False,
@@ -477,7 +509,7 @@ def run_all(
     timeout,
     retry,
 ):
-    from .odoo_config import MANIFEST, customs_dir
+    from .odoo_config import customs_dir
     from .robo_helpers import _get_all_robottest_files
     from .odoo_config import customs_dir
 
@@ -485,17 +517,23 @@ def run_all(
         abort("Devmode required to run robotests")
     customsdir = customs_dir()
 
-    if debug:
-        _setup_visual_code_robot(ctx, config)
+    # if debug:
+    #     _setup_visual_code_robot(ctx, config)
 
     files = _get_all_robottest_files()
     files = [customsdir / file for file in files]
 
+    click.secho("Testing following files:")
+    for file in files:
+        click.secho(f"  {file}", fg="green")
+
     for file in files:
         click.secho(f"Running robotest {file}")
 
         for i in range(retry):
-            click.secho(f"Try #{i + 1} of {retry}")
+            click.secho(
+                f"Try #{i + 1} of {retry} for {file.parent}/{file.name}"
+            )
             try:
                 res = ctx.invoke(
                     run,
@@ -508,7 +546,8 @@ def run_all(
             except Exception as ex:
                 retry += 1
                 click.secho(
-                    f"Retry at _prepare_fresh_robotest because of {ex}", fg="yellow"
+                    f"Retry at _prepare_fresh_robotest because of {ex}",
+                    fg="yellow",
                 )
                 time.sleep(random.randint(20, 60))
 
@@ -587,13 +626,14 @@ def make_variable_file(ctx, config, userpassword=None):
     if not path.exists():
         path.write_text("{}")
     data = json.loads(path.read_text())
-    data.setdefault("TOKEN", 1)
+    data.setdefault("TOKEN", 100)
     if userpassword:
-        data["ODOO_PASSWORD"] = userpassword
-    data["ODOO_PORT"] = int(config.PROXY_PORT)
-    data["ODOO_USER"] = "admin"
-    data["ODOO_DB"] = config.DBNAME
-    data["ODOO_VERSION"] = str(current_version())
+        data["ROBO_ODOO_PASSWORD"] = userpassword
+    data.setdefault("ROBO_ODOO_PASSWORD", "admin")
+    data["ROBO_ODOO_PORT"] = int(config.PROXY_PORT)
+    data["ROBO_ODOO_USER"] = "admin"
+    data["ROBO_ODOO_DB"] = config.DBNAME
+    data["ROBO_ODOO_VERSION"] = current_version()
     data["TEST_RUN_INDEX"] = 0
     data["TEST_DIR"] = str(customs_dir() / "robot-output")
     Path(data["TEST_DIR"]).mkdir(exist_ok=True)
@@ -602,4 +642,18 @@ def make_variable_file(ctx, config, userpassword=None):
     __assure_gitignore(customs_dir() / ".gitignore", ".robot-vars")
 
 
+@robot.command(name="list", help="Creates .robot-vars")
+@pass_config
+@click.pass_context
+def do_list(ctx, config):
+    from .robo_helpers import _get_all_robottest_files
+
+    files = _get_all_robottest_files()
+    click.secho("!!!")
+    for file in files:
+        click.secho(file)
+    click.secho("!!!")
+
+
 Commands.register(make_variable_file, "robot:make-var-file")
+Commands.register(run, "robot:run")
