@@ -361,9 +361,6 @@ def _wait_postgres(config, timeout=600):
             .splitlines()
         )
 
-        import docker
-
-        client = docker.from_env()
         postgres_containers = []
         for container_id in container_ids:
             if not container_id:
@@ -540,7 +537,9 @@ def __dc_out(config, cmd, env={}, profile="auto"):
     ensure_project_name(config)
     c = __get_cmd(config, profile=profile) + cmd
     env = _set_default_envs(env)
-    return subprocess.check_output(c, env=_merge_env_dict(env))
+    return subprocess.check_output(
+        c, env=_merge_env_dict(env), encoding="utf8"
+    )
 
 
 def __dcexec(config, cmd, interactive=True, env=None):
@@ -700,9 +699,10 @@ def __get_cmd(config, profile="auto"):
         cmd = config.commands["dc2"]
     else:
         cmd = config.commands["dc"]
-    if profile:
-        if "--profile" not in cmd:
-            cmd += ["--profile", profile]
+    if isinstance(profile, str):
+        profile = [profile]
+    for profile in profile or []:
+        cmd += ["--profile", profile]
     cmd = [os.path.expandvars(x) for x in cmd]
     return cmd
 
@@ -712,15 +712,16 @@ def __cmd_interactive(config, *params):
     tty = sys.stdin.isatty()
     params = {}
     if not tty:
-        cmd = [x for x in cmd if x not in ['-it', '--interactive', '--tty']]
-        params['capture_output'] = True
-        params['text'] = True
+        cmd = [x for x in cmd if x not in ["-it", "--interactive", "--tty"]]
+        params["capture_output"] = True
+        params["text"] = True
     res = subprocess.run(cmd, **params)
     if res.returncode:
         click.secho(
             f"Command failed with return code: {res.returncode}:\n{cmd}\n\n{res.stdout}\n{res.stderr}",
             fg="red",
         )
+    return res.returncode
 
     # ctrl+c leads always to error otherwise
     # if proc.returncode:
@@ -1916,3 +1917,75 @@ def _get_available_modules(ctx, param, incomplete):
 def is_interactive():
     v = os.getenv("WODOO_INTERACTIVE", "1")
     return v == "1"
+
+
+def create_network(name="aptcache-net"):
+    # Check if the network already exists
+    result = subprocess.run(
+        [
+            "docker",
+            "network",
+            "ls",
+            "--filter",
+            f"name=^{name}$",
+            "--format",
+            "{{.Name}}",
+        ],
+        capture_output=True,
+        text=True,
+    )
+
+    if name in result.stdout.splitlines():
+        click.secho(f"Network '{name}' already exists.", fg="green")
+        return
+
+    # Create the network
+    click.secho(f"Creating Docker network '{name}'...", fg="yellow")
+    try:
+        subprocess.run(["docker", "network", "create", name], check=True)
+        click.secho(f"Network '{name}' created successfully.", fg="green")
+    except subprocess.CalledProcessError as e:
+        abort(str(e))
+
+
+def remove_comments(content):
+    content = [
+        line.strip()
+        for line in content
+        if line.strip() and not line.startswith("#")
+    ]
+    return content
+
+
+def copy_into_docker(strcontent, container_name, dest_path):
+    with autocleanpaper() as tfile:
+        tfile.write_text(strcontent)
+
+        subprocess.run(
+            [
+                "docker",
+                "cp",
+                tfile,
+                f"{container_name}:{dest_path}",
+            ]
+        )
+
+
+def docker_get_file_content(container_name, file_path):
+    content = (
+        subprocess.run(
+            [
+                "docker",
+                "exec",
+                container_name,
+                "cat",
+                file_path,
+            ],
+            capture_output=True,
+            text=True,
+            check=True,
+        )
+        .stdout.strip()
+        .splitlines()
+    )
+    return content
