@@ -7,8 +7,8 @@ def timeout(func):
     def _timeout(*args, **kwargs):
         TIMEOUT = 300
 
-        if 'timeout' in kwargs:
-            TIMEOUT = kwargs['timeout']
+        if "timeout" in kwargs:
+            TIMEOUT = kwargs["timeout"]
 
         start = time.time()
 
@@ -24,4 +24,5 @@ def timeout(func):
 
     return _timeout
 
+
 # vim: tabstop=4 expandtab shiftwidth=4 softtabstop=4
